<?php

namespace App\Models;

use App\Models\User;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\HasOne;

class BlogPost extends Model
{
    use HasFactory;

    protected $fillable = [
        'question_id',
        'description',
        'public_status',
        'date', 'status',
        'created_by',
        'updated_by',
        'valid'
    ];

    public function user(): BelongsTo
    {
        return $this->belongsTo(User::class, 'created_by', 'id');
    }

    public function blogFile(): HasOne
    {
        return $this->hasOne(BlogFile::class, 'blog_post_id', 'id');
    }

    public function question(): BelongsTo
    {
        return $this->belongsTo(Question::class, 'question_id', 'id');
    }

    public function comments(): HasMany
    {
        return $this->hasMany(PostComment::class, 'blog_post_id', 'id')
            ->where('parent_id', 0);
    }

    public function likes(): HasMany
    {
        return $this->hasMany(PostLike::class, 'blog_post_id', 'id');
    }
}
